.. _srctype_step:

===================================
Source Type (SRCTYPE) Determination
===================================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.srctype
